#ifndef AMAUDITTYPES_H_SOURCECODEID
#define AMAUDITTYPES_H_SOURCECODEID
static char amaudittypes_h_sourceCodeID[]="$Id: @(#)75  1.13 src/ivaudit/amaudittypes.h, pd.audit, am700 06/09/11 10:07:49 @(#) $";
#endif    /* AMAUDITTYPES_H_SOURCECODEID */

/*
 * Licensed Materials - Property of IBM
 * 5748-XX8
 * (c) Copyright International Business Machines Corp. 2001
 * All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplicaion or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 * Copyright (C) Tivoli Systems/IBM.  2000
 *
 * NAME
 *     pdaudit - Policy Director Auditing Service header
 *
 * DESCRIPTION
 *     This header file contains the definitions of Auditing Service
 *     specific macros and the "C" API functions prototypes.
 */

#ifndef AM_AUDITTYPES_H
#define AM_AUDITTYPES_H

#include <IVTypes.h>
/* #include <carsdefs.h> - can't do this since amaudittypes.h is shipped. */

typedef enum PDAuditEnumResource {
    PD_AUDIT_RESOURCE_AZN,
    PD_AUDIT_RESOURCE_PROCESS,
    PD_AUDIT_RESOURCE_TCB,
    PD_AUDIT_RESOURCE_CREDENTIAL,
    PD_AUDIT_RESOURCE_POLICY,
    PD_AUDIT_RESOURCE_GENERAL,
    PD_AUDIT_RESOURCE_APPLICATION,
    PD_AUDIT_RESOURCE_AUTHENTICATION
} PDAuditEnumResource;

typedef enum PDAuditEnumSystem {
    PD_AUDIT_SYSTEM_UNIX,
    PD_AUDIT_SYSTEM_NT
} PDAuditEnumSystem;

typedef enum AMAuditEnumOutcome {
    PD_AUDIT_OUTCOME_SUCCESS,            /* Success  (and for AUTHZ also accessDecision "permitted") */
    PD_AUDIT_OUTCOME_FAILURE,            /* Failure  (for AUTHZ maps to outcome "success" and accessDecision "denied") */
    PD_AUDIT_OUTCOME_PENDING,            /*  not used */
    PD_AUDIT_OUTCOME_UNKNOWN,            /* AUTHZ only - maps to outcome "failure" and access decision unknown  */
    PD_AUDIT_OUTCOME_PERMITTED_WARNING,  /* AUTHZ only - maps to outcome "success" and access decision "permittedWarning" */
    PD_AUDIT_OUTCOME_DENIED              /* AUTHZ only - new for am600 - "success" and accessDecaision "denied" */
} AMAuditEnumOutcome;
#define PDAuditEnumOutcome AMAuditEnumOutcome
#define PD_AUDIT_CHECK_ALL_OUTCOMES  ((AMAuditEnumOutcome)0xFF)
/**********************************************************************************/
/*  outcome to Common Audit outcome.result mapping:                               */
/*  ---------------------------------                                             */
/*   if  not AUDIT_AUTHZ if outcome = SUCCESS then                                */
/*     outcome.result = CARS_OUTCOME_RESULT_SUCCESSFUL                            */
/*   otherwise                                                                    */
/*     outcome.result = CARS_OUTCOME_RESULT_UNSUCCESSFUL                          */
/*                                                                                */
/*  if AUDIT_AUTHZ                                                                */
/*   if  outcome=PERMITTED,PERMITTED_WARNING, PENDING, or FAILURE,  then          */
/*     outcome.result =CARS_OUTCOME_ RESULT_SUCCESSFUL                            */
/*   otherwise (an accessDecision could not be made because of an error)          */
/*    outcome.result =CARS_OUTCOME_RESULT_UNSUCCESSFUL                            */
/*                                                                                */
/*  outcome to accessDecision mapping:                                            */
/*  ------------------------------------                                          */
/*   if PD_AUDIT_ACTION_AUTHZ or PD_AUDIT_ACTION_RESOURCE_ACCESS                  */
/*    if outcome=PD_AUDIT_OUTCOME_SUCCESS then                                    */
/*     accessDecision = CARS_AUDIT_AUTHZ_ ACCESSDECISION_permitted                */
/*    else if outcome = PD_AUDIT_OUTCOME_PERMITTED_WARNING then                   */
/*     accessDecision = CARS_AUDIT_AUTHZ_ ACCESS DECISION_permittedWarning        */
/*    else if FAILURE then                                                        */
/*     accessDecision =CARS_AUDIT_AUTHZ_ACCESS DECISION_denied                    */
/*    otherwise                                                                   */
/*     accessDecision = CARS_AUDIT_AUTHZ_ ACCESSDECISION_unknown                  */
/*                                                                                */
/**********************************************************************************/

#ifdef __cplusplus
extern "C" {
#endif
typedef IVTbool (*AMAuditFilterFunction)(const IVTuint32, const AMAuditEnumOutcome);
#define PDAuditFilterFunction AMAuditFilterFunction
#ifdef __cplusplus
}
#endif

/* Override the pdAuditCommon's cred fields using PDAuditEventSetNameValue */
#define PD_AUDIT_COMMON_RESOURCE              "amtrc resource"
#define PD_AUDIT_VALUE_RESOURCE_AZN             "0"
#define PD_AUDIT_VALUE_RESOURCE_PROCESS         "1"
#define PD_AUDIT_VALUE_RESOURCE_TCB             "2"
#define PD_AUDIT_VALUE_RESOURCE_CREDENTIAL      "3"
#define PD_AUDIT_VALUE_RESOURCE_POLICY          "4"
#define PD_AUDIT_VALUE_RESOURCE_GENERAL         "5"
#define PD_AUDIT_VALUE_RESOURCE_APPLICATION     "6"
#define PD_AUDIT_VALUE_RESOURCE_AUTHENTICATION  "7"

#define PD_AUDIT_COMMON_ORIGINATING_LOCATION   "amtrc location"

#define PD_AUDIT_COMMON_LINKAGE                "amtrc link"

#define PD_AUDIT_COMMON_FAIL_STATUS            "amtrc status"

#define PD_AUDIT_COMMON_PROTECTED_OBJECT       "amtrc target"

/* Generic string for a null or not specified field.                                   */
/* Use for unspecified PD_AUDIT_CRED_USER_INFO/MECH_ID/PRINCIPAL_NAME/PRINCIPAL_DOMAIN */
/* #define PD_AUDIT_VALUE_NOTSPECIFIED            "Not specified"                      */

/* Process Information, will be added to audit record if any of these are set... */
#define PD_AUDIT_COMMON_SYSTEM                 "amtrc architecture"
#define PD_AUDIT_VALUE_SYSTEM_UNIX              "0"
#define PD_AUDIT_VALUE_SYSTEM_WINDOWS           "1"

#define PD_AUDIT_COMMON_PID                    "amtrc pid"
#define PD_AUDIT_COMMON_UID                    "amtrc uid"
#define PD_AUDIT_COMMON_EID                    "amtrc eid"
#define PD_AUDIT_COMMON_GID                    "amtrc gid"
#define PD_AUDIT_COMMON_EGID                   "amtrc egid"
/* End of Process Information */

/* AZN Information, will be added to audit record if any of these are set... */
#define PD_AUDIT_COMMON_AZN_PERMISSION         "amtrc permission"
#define PD_AUDIT_COMMON_AZN_RESULT             "amtrc result"

#define PD_AUDIT_COMMON_AZN_RESULT_QUALIFIER   "amtrc qualifier"
/* End of AZN Information */

/* Audited Attributes from a user's credential */
#define PD_AUDIT_CRED_USER_INFO         "amtrc accessor name"
#define PD_AUDIT_CRED_MECH_ID           "amtrc principal auth"
#define PD_AUDIT_CRED_PRINCIPAL_NAME    "amtrc principal"
#define PD_AUDIT_CRED_PRINCIPAL_RGY_NAME    "amtrc prncpl rgy"  /* User's name in registry */
#define PD_AUDIT_CRED_PRINCIPAL_DOMAIN  "amtrc principal domain"

/* special case values for credential attributes */

#define PD_AUDIT_VALUE_MECH_ID_NULL   "Not specified"
/* If the credential's mech id is 0, then set the audit mech id using
    PDAuditEventSetNameValue(event_h,
                             PD_AUDIT_CRED_MECH_ID,
                             PD_AUDIT_VALUE_MECH_ID_NULL,
                             &status)
*/

#define PD_AUDIT_VALUE_PRINCIPAL_DOMAIN_NULL   "Default"
/* If the credential's principal domain is 0, then set the domain using
    PDAuditEventSetNameValue(event_h,
                             PD_AUDIT_CRED_PRINCIPAL_DOMAIN,
                             PD_AUDIT_VALUE_PRINCIPAL_DOMAIN_NULL,
                             &status)
*/


#define PD_AUDIT_VALUE_PRINCIPAL_UNAUTH     "Unauth"
/* If credential's mech id is "unauth", then use
    PDAuditEventSetNameValue(event_h,
                             PD_AUDIT_CRED_PRINCIPAL_NAME,
                             PD_AUDIT_VALUE_PRINCIPAL_UNAUTH,
                             &status)
*/

/*
 * Audit Record Version
 */
#define PD_AUDIT_RECORD_REV     0x102

/*
 Audit interface text character encoding
*/
#define AM_AUDIT_ENCODING_UTF8 "UTF8"
#define PD_AUDIT_ENCODING_UTF8 AM_AUDIT_ENCODING_UTF8
#define AM_AUDIT_ENCODING_LCP  NULL
#define PD_AUDIT_ENCODING_LCP  AM_AUDIT_ENCODING_LCP


/* -------------------------------------------------------------------------------- */
/*                            policy and attribute definitions                      */
#define PDAUDIT_NAME "name"
#define PDAUDIT_TYPE "type"
#define PDAUDIT_DESCRIPTION "description"
#define PDAUDIT_SOURCE "source"
#define PDAUDIT_VALUE "value"

#define PD_AUDIT_VALUE_POLICY_TYPE_ACL "ACL"
#define PD_AUDIT_VALUE_POLICY_TYPE_POP "POP"
#define PD_AUDIT_VALUE_POLICY_TYPE_RULE "rule"

#define PD_AUDIT_VALUE_ATTRIBUTE_TYPE_STRING "string"
#define PD_AUDIT_VALUE_ATTRIBUTE_TYPE_ULONG "ulong"
#define PD_AUDIT_VALUE_ATTRIBUTE_TYPE_POBJ "pobj"
#define PD_AUDIT_VALUE_ATTRIBUTE_TYPE_BUFFER "buffer"

#define PD_AUDIT_VALUE_ATTRIBUTE_SOURCE_CRED "cred"
#define PD_AUDIT_VALUE_ATTRIBUTE_SOURCE_APP "app"
#define PD_AUDIT_VALUE_ATTRIBUTE_SOURCE_CREDADI "credADI"
#define PD_AUDIT_VALUE_ATTRIBUTE_SOURCE_APPADI "appADI"
#define PD_AUDIT_VALUE_ATTRIBUTE_SOURCE_ENGINEADI "engineADI"
#define PD_AUDIT_VALUE_ATTRIBUTE_SOURCE_DYNADI "dynADI"

typedef enum PDAuditEnumAttributeSource {
    PD_AUDIT_ATTRIBUTE_SOURCE_CRED,
    PD_AUDIT_ATTRIBUTE_SOURCE_APP,
    PD_AUDIT_ATTRIBUTE_SOURCE_CREDADI,   /* Not Used */
    PD_AUDIT_ATTRIBUTE_SOURCE_APPADI,    /* Not Used */
    PD_AUDIT_ATTRIBUTE_SOURCE_ENGINEADI, /* Not Used */
    PD_AUDIT_ATTRIBUTE_SOURCE_DYNADI     /* This is used to represent any of the three above */
} PDAuditEnumAttributeSource;

typedef enum PDAuditEnumAttributeType {
    PD_AUDIT_ATTRIBUTE_TYPE_STRING,
    PD_AUDIT_ATTRIBUTE_TYPE_ULONG,
    PD_AUDIT_ATTRIBUTE_TYPE_POBJ,
    PD_AUDIT_ATTRIBUTE_TYPE_BUFFER
} PDAuditEnumAttributeType;

typedef enum PDAuditEnumPolicyType {
    PD_AUDIT_POLICY_TYPE_ACL,
    PD_AUDIT_POLICY_TYPE_POP,
    PD_AUDIT_POLICY_TYPE_RULE
} PDAuditEnumPolicyType;




/* -------------------------------------------------------------------------------- */
/*                            Common Audit definitions                              */

/* PD_AUDIT_ACTION_* values can be used as values for the EventStart id parameter. */
/* The event id field is interpreted and documented for the following values... */


/* The PD_AUDIT_LEGACY_ACTION nameValue name is defined to allow mapping of new PD_AUDIT_ACTION_* */
/* actions back into LEGACY actions for legacy audit logging.   AMAudit will map known ACTION_*   */
/* values back into legacy ACTION_* values, if possible.   Applications can use the               */
/* PD_AUDIT_LEGACY_ACTION directly to map actions that AMAudit doesn't recognize.                 */
#define PD_AUDIT_LEGACY_ACTION                "amtrc legacyaction"

/* The following LEGACY actions should not be used for the event_id.                              */
/* They are supported for backward compatibility of the old action log element.                   */
/* Set these into the PD_AUDIT_LEGACY_ACTION namevalue if AMAudit doesn't recognize your event_id.*/
#define PD_AUDIT_LEGACY_ACTION_AUTHN                        0
#define PD_AUDIT_LEGACY_ACTION_PWCHANGE                     1
#define PD_AUDIT_LEGACY_ACTION_AUTHZ                        0
#define PD_AUDIT_LEGACY_ACTION_RESOURCE_ACCESS              2
/* Authentication Actions for Web Plugin - note that AMAudit will not attempt to map these. */
#define PD_AUDIT_LEGACY_ACTION_AUTHN_BA                 16961
#define PD_AUDIT_LEGACY_ACTION_AUTHN_CERT               17236
#define PD_AUDIT_LEGACY_ACTION_AUTHN_ECSSO              17731
#define PD_AUDIT_LEGACY_ACTION_AUTHN_FAILOVER_COOKIE    17999
#define PD_AUDIT_LEGACY_ACTION_AUTHN_FORMS              17997
#define PD_AUDIT_LEGACY_ACTION_AUTHN_HTTPHDR            18504
#define PD_AUDIT_LEGACY_ACTION_AUTHN_IPADDR             18768
#define PD_AUDIT_LEGACY_ACTION_AUTHN_IVHDR_PAC        4806211
#define PD_AUDIT_LEGACY_ACTION_AUTHN_IVHDR_USERNAME   4806229
#define PD_AUDIT_LEGACY_ACTION_AUTHN_IVHDR_DN         4806220
#define PD_AUDIT_LEGACY_ACTION_AUTHN_IVHDR_IPADDR      300609
#define PD_AUDIT_LEGACY_ACTION_AUTHN_TOKEN              21579


/* Authentication                            */
#define PD_AUDIT_ACTION_AUTHN_LOGIN                101
#define PD_AUDIT_ACTION_PASSWORD_CHANGE            102
#define PD_AUDIT_ACTION_AUTHN_TERMINATE            103

/* Standard CARS AUTHN Actions */
#define PD_AUDIT_ACTION_AUTHENTICATE               104
#define PD_AUDIT_ACTION_STEPUP                     105
#define PD_AUDIT_ACTION_REAUTHENTICATION           106
#define PD_AUDIT_ACTION_CREDS_REFRESH              107

#define PD_AUDIT_ACTION_AUTHZ                      108
#define PD_AUDIT_ACTION_RESOURCE_ACCESS            109

#define PD_AUDIT_ACTION_GET_CREDS                  110
#define PD_AUDIT_ACTION_CREDS_MODIFY               111
#define PD_AUDIT_ACTION_CREDS_COMBINE              111
#define PD_AUDIT_ACTION_GET_CREDS_FROM_PAC         112
#define PD_AUDIT_ACTION_GET_PAC                    113
#define PD_AUDIT_ACTION_GET_ENTITLEMENTS           114
#define PD_AUDIT_ACTION_PDOBJ_GET_ENTITLEMENTS     114

#define PD_AUDIT_ACTION_RUNTIME_START              115
#define PD_AUDIT_ACTION_RUNTIME_STOP               116
#define PD_AUDIT_ACTION_RUNTIME_AUDIT_START        117
#define PD_AUDIT_ACTION_RUNTIME_AUDIT_STOP         118
#define PD_AUDIT_ACTION_RUNTIME_AUDIT_LEVEL_CHANGE 119
#define PD_AUDIT_ACTION_RUNTIME_STATISTIC          120
#define PD_AUDIT_ACTION_RUNTIME_HEARTBEAT_UP       121
#define PD_AUDIT_ACTION_RUNTIME_HEARTBEAT_DOWN     122
#define PD_AUDIT_ACTION_RUNTIME_LOST_CONTACT       123
#define PD_AUDIT_ACTION_RUNTIME_CONTACT_RESTORED   124
#define PD_AUDIT_ACTION_RUNTIME_MONITOR            125

#define PD_AUDIT_ACTION_AUTHN_SWITCHUSER           126
#define PD_AUDIT_ACTION_AUTHN_SWITCHUSER_TERMINATE 127

#define PD_AUDIT_ACTION_LAST                       127

/* Unless noted, the PD_AUDIT_CARS attributes are for Common Auditing  */
/* only, and do not get written to the legacy audit log. */

/* NAME_IN_POLICY is the same as the legacy PD_AUDIT_COMMON_PROTECTED_OBJECT  */
#define PD_AUDIT_CARS_RESOURCE_NAME_IN_POLICY       "amtrc target"
#define PD_AUDIT_CARS_RESOURCE_NAME_IN_APP          "amtrc nameinapp"
#define PD_AUDIT_CARS_INSTANCE_ID                   "amtrc instanceid"
#define PD_AUDIT_CARS_FAIL_STATUS_MAJOR             "amtrc majorstatus"

#define PD_AUDIT_CRED_SU_ADMIN                      "amtrc suadmin"
#define PD_AUDIT_CRED_SESSION_ID                    "amtrc sessionid"

#define PD_AUDIT_CARS_USER_LOCATION                 "amtrc userloc"
#define PD_AUDIT_CARS_USER_LOCATION_TYPE            "amtrc userloctype"

#define PD_AUDIT_CARS_REASON                        "amtrc reason"
#define PD_AUDIT_CARS_ACCESS_DECISION_REASON        "amtrc reason"
#define PD_AUDIT_CARS_FAILURE_REASON                "amtrc reason"
/* for reason, use PD_AUDIT_CARS_REASON_UNKNOWN or one of the cars defines for reason: */
#define PD_AUDIT_CARS_REASON_UNKNOWN                "application specific"
/* cars defines for reason:
 FailureReason / AccessDecisionReason values
 - usually used if AUDIT_AUTHZ or AUDIT_RESOURCE_ACCESS, and outcome is failed (denied)
 CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_delegateUnauthorized
 CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_authzRuleUnauthorized
 CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_timeOfDayUnauthorized
 CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_unauthorized
 CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_qopUnauthorized
 CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_authnLevelUnauthorized
 CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_reauthnUnauthorized

 CARS_AUDIT_AUTHN_FAILUREREASON_accountDisabledRetryViolation
 CARS_AUDIT_AUTHN_FAILUREREASON_accountLockedOutRetryViolation
 CARS_AUDIT_AUTHN_FAILUREREASON_accountLockedOutMaxLoginFail
 CARS_AUDIT_AUTHN_FAILUREREASON_accountDisabled
 CARS_AUDIT_AUTHN_FAILUREREASON_accountExpired
 CARS_AUDIT_AUTHN_FAILUREREASON_accountUnlocked
 CARS_AUDIT_AUTHN_FAILUREREASON_accountMaxInactiveElapsed
 CARS_AUDIT_AUTHN_FAILUREREASON_passwordExpired
 CARS_AUDIT_AUTHN_FAILUREREASON_passwordChangeMinIntervalUnexpired
 CARS_AUDIT_AUTHN_FAILUREREASON_passwordChangeMaxIntervalElapsed
 CARS_AUDIT_AUTHN_FAILUREREASON_authenticationFailure
 CARS_AUDIT_AUTHN_FAILUREREASON_invalidUserName
 CARS_AUDIT_AUTHN_FAILUREREASON_pinRequired
 CARS_AUDIT_AUTHN_FAILUREREASON_nextToken
 CARS_AUDIT_AUTHN_FAILUREREASON_mappingFailure
 CARS_AUDIT_AUTHN_FAILUREREASON_certificateFailure
 CARS_AUDIT_AUTHN_FAILUREREASON_policyViolation
 CARS_AUDIT_AUTHN_FAILUREREASON_policyViolationTOD
 CARS_AUDIT_AUTHN_FAILUREREASON_policyAllowedAccess
 CARS_AUDIT_AUTHN_FAILUREREASON_policyViolationMaxLoginsReached
 CARS_AUDIT_AUTHN_FAILUREREASON_usernameMismatch
 CARS_AUDIT_AUTHN_FAILUREREASON_invalidUserPassword
 CARS_AUDIT_AUTHN_FAILUREREASON_tokenSignatureValidationFailed
 CARS_AUDIT_AUTHN_FAILUREREASON_tokenExpired
 CARS_AUDIT_AUTHN_FAILUREREASON_tokenNotValidYet
 CARS_AUDIT_AUTHN_FAILUREREASON_tokenNotSupported
 CARS_AUDIT_AUTHN_FAILUREREASON_tokenNotInValidFormat

 CARS_AUDIT_AUTHN_FAILUREREASON_invalidOperation
 CARS_AUDIT_AUTHN_FAILUREREASON_httpHeaderAuthnFailure
 CARS_AUDIT_AUTHN_FAILUREREASON_invalidAuthnInfo
 CARS_AUDIT_AUTHN_FAILUREREASON_loginPolicyViolation
 CARS_AUDIT_AUTHN_FAILUREREASON_certAuthFailure
 CARS_AUDIT_AUTHN_FAILUREREASON_ipAddrAuthFailure
 CARS_AUDIT_AUTHN_FAILUREREASON_postPwdChangeFail
*/


/* Some of the following constants are also defined in file "carsdefs.h" which
 * exists in pdbsup.
 */

#ifndef CARS_OUTCOME_FAILUREREASON_invalidOperation
#define CARS_OUTCOME_FAILUREREASON_invalidOperation "invalidOperation"
#endif
#ifndef CARS_OUTCOME_FAILUREREASON_passwordSpaces
#define CARS_OUTCOME_FAILUREREASON_passwordSpaces "passwordSpaces"
#endif
#ifndef CARS_AUDIT_AUTHN_FAILUREREASON_httpHeaderAuthnFailure
#define CARS_AUDIT_AUTHN_FAILUREREASON_httpHeaderAuthnFailure "httpHeaderAuthnFailure"
#endif
#ifndef CARS_AUDIT_AUTHN_FAILUREREASON_invalidAuthnInfo
#define CARS_AUDIT_AUTHN_FAILUREREASON_invalidAuthnInfo "invalidAuthnInfo"
#endif
#ifndef CARS_AUDIT_AUTHN_FAILUREREASON_loginPolicyViolation
#define CARS_AUDIT_AUTHN_FAILUREREASON_loginPolicyViolation "loginPolicyViolation"
#endif
#ifndef CARS_AUDIT_AUTHN_FAILUREREASON_certAuthFailure
#define CARS_AUDIT_AUTHN_FAILUREREASON_certAuthFailure "certAuthFailure"
#endif
#ifndef CARS_AUDIT_AUTHN_FAILUREREASON_ipAddrAuthFailure
#define CARS_AUDIT_AUTHN_FAILUREREASON_ipAddrAuthFailure "ipAddrAuthFailure"
#endif
#ifndef CARS_AUDIT_AUTHN_FAILUREREASON_postPwdChangeFail
#define CARS_AUDIT_AUTHN_FAILUREREASON_postPwdChangeFail "postPwdChangeFail"
#endif
#ifndef CARS_AUDIT_AUTHN_FAILUREREASON_passwordPolicyViolation
#define CARS_AUDIT_AUTHN_FAILUREREASON_passwordPolicyViolation "passwordPolicyViolation"
#endif
#ifndef CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_delegateUnauthorized_warningMode
#define CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_delegateUnauthorized_warningMode "delegateUnauthorized_warningMode"
#endif
#ifndef CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_authzRuleUnauthorized_warningMode
#define CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_authzRuleUnauthorized_warningMode "authzRuleUnauthorized_warningMode"
#endif
#ifndef CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_timeOfDayUnauthorized_warningMode
#define CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_timeOfDayUnauthorized_warningMode "timeOfDayUnauthorized_warningMode"
#endif
#ifndef CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_aclUnauthorized
#define CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_aclUnauthorized "aclUnauthorized"
#endif
#ifndef CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_aclUnauthorized_warningMode
#define CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_aclUnauthorized_warningMode "aclUnauthorized_warningMode"
#endif


/* defect 65799 */
#ifndef CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_traverseUnauthorized_warningMode
#define CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_traverseUnauthorized_warningMode "traverseUnauthorized_warningMode"
#endif
#ifndef CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_traverseUnauthorized
#define CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_traverseUnauthorized "traverseUnauthorized"
#endif

#ifndef CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_stepupForbidden
#define CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_stepupForbidden  "stepupForbidden"
#endif
#ifndef CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_stepupForbidden_warningMode
#define CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_stepupForbidden_warningMode  "stepupForbidden_warningMode"
#endif

#ifndef CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_easUnauthorized_warningMode
#define CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_easUnauthorized_warningMode "easUnauthorized_warningMode"
#endif
#ifndef CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_easUnauthorized
#define CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_easUnauthorized "easUnauthorized"
#endif

#ifndef CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_easOverrideUnauthorized_warningMode
#define CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_easOverrideUnauthorized_warningMode "easOverrideUnauthorized_warningMode"
#endif
#ifndef CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_easOverrideUnauthorized
#define CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_easOverrideUnauthorized "easOverrideUnauthorized"
#endif
/* end of defect 65799 */

#ifndef CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_stepupRequired
#define  CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_stepupRequired "stepupRequired"
#endif
#ifndef CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_easOverrideAuthorized
#define CARS_AUDIT_AUTHZ_ACCESSDECISIONREASON_easOverrideAuthorized "easOverrideAuthorized"
#endif

#define PD_AUDIT_CARS_TRAIL_ID                      "amtrc trailid"
#define PD_AUDIT_CARS_START_TIME                    "amtrc starttime"
#define PD_AUDIT_CARS_STOP_TIME                     "amtrc stoptime"
#define PD_AUDIT_CARS_AUTHN_TERMINATE_LOGIN_TIME    "amtrc logintime"
#define PD_AUDIT_CARS_AUTHN_TERMINATE_REASON        "amtrc termreason"
/*
 CARS_AUDIT_AUTHN_TERMINATE_TERMINATEREASON_idleTimeout
 CARS_AUDIT_AUTHN_TERMINATE_TERMINATEREASON_sessionExpired
 CARS_AUDIT_AUTHN_TERMINATE_TERMINATEREASON_sessionDisplaced
 CARS_AUDIT_AUTHN_TERMINATE_TERMINATEREASON_sessionTerminatedByAdmin
 CARS_AUDIT_AUTHN_TERMINATE_TERMINATEREASON_userLoggedOut
*/

/* AUDIT_AUTHN authenProvider */
#define PD_AUDIT_AUTHN_PROVIDER                        "amtrc authnprovider"

/* AUDIT_AUTHN authnType */
#define PD_AUDIT_AUTHN_TYPE                         "amtrc authntype"
/* authnType values */
#define PD_AUDIT_AUTHN_TYPE_basicAuthRFC2617            "basicAuthRFC2617"
#define PD_AUDIT_AUTHN_TYPE_itamECSSO                   "itamECSSO"
#define PD_AUDIT_AUTHN_TYPE_itamFailoverCookie          "itamFailoverCookie"
#define PD_AUDIT_AUTHN_TYPE_formsPassword               "formsPassword"
#define PD_AUDIT_AUTHN_TYPE_itamIVCreds                 "itamIVCreds"
#define PD_AUDIT_AUTHN_TYPE_itamIVUser                  "itamIVUser"
#define PD_AUDIT_AUTHN_TYPE_itamCDSSO                   "itamCDSSO"
#define PD_AUDIT_AUTHN_TYPE_itamEAI                     "itamEAI"
#define PD_AUDIT_AUTHN_TYPE_certificate                 "certificate"
#define PD_AUDIT_AUTHN_TYPE_itamHTTPHeader              "itamHTTPHeader"
#define PD_AUDIT_AUTHN_TYPE_itamIPAddress               "itamIPAddress"
#define PD_AUDIT_AUTHN_TYPE_tokenLTPA                   "tokenLTPA"
#define PD_AUDIT_AUTHN_TYPE_twoFactor                   "twoFactor"
#define PD_AUDIT_AUTHN_TYPE_unauth                      "unauth"
#define PD_AUDIT_AUTHN_TYPE_kerberos                    "kerberos"
#define PD_AUDIT_AUTHN_TYPE_ntlm                        "ntlm"
#define PD_AUDIT_AUTHN_TYPE_itamWebServerAuthentication "itamWebServerAuthentication"
#define PD_AUDIT_AUTHN_TYPE_passwordOther               "passwordOther"


/* The following three are logically the same */
#define PD_AUDIT_CARS_AUTHN_PROGNAME                "amtrc appname"
#define PD_AUDIT_CARS_AUTHZ_APPNAME                 "amtrc appname"
#define PD_AUDIT_CARS_RESOURCE_ACCESS_APPNAME       "amtrc appname"
/* If not specified, AM Audit will get appname from blade - the process name */

#define PD_AUDIT_CARS_RESOURCE_ACCESS_TYPE    "amtrc rsrcaction"
#define PD_AUDIT_CARS_RESOURCE_ACCESS_ACTION  "amtrc rsrcaction"
/* use:
 CARS_AUDIT_RESOURCE_ACCESS_ACTION_fileTrace
 CARS_AUDIT_RESOURCE_ACCESS_ACTION_fileExec
 CARS_AUDIT_RESOURCE_ACCESS_ACTION_httpRequest
*/

#define PD_AUDIT_CARS_AZN_QOP                       "amtrc qop"
/* use the following for qop */
#define PD_AUDIT_CARS_AZN_QOP_VALUE_NONE            "none"
#define PD_AUDIT_CARS_AZN_QOP_VALUE_INTEGRITY       "integrity"
#define PD_AUDIT_CARS_AZN_QOP_VALUE_PRIVACY         "privacy"


#define PD_AUDIT_CARS_CRED_SESSION_ID               "amtrc sessionid"

#define PD_AUDIT_CARS_RESOURCE_TYPE                 "amtrc rsrc type"
/* use:
  CARS_RESOURCE_INFO_TYPE_user
  CARS_RESOURCE_INFO_TYPE_orgContainer
  CARS_RESOURCE_INFO_TYPE_group
  CARS_RESOURCE_INFO_TYPE_provisioningPolicy
  CARS_RESOURCE_INFO_TYPE_identityPolicy
  CARS_RESOURCE_INFO_TYPE_serviceSelectionPolicy
  CARS_RESOURCE_INFO_TYPE_passwordPolicy
  CARS_RESOURCE_INFO_TYPE_provisioningResource
  CARS_RESOURCE_INFO_TYPE_provisioningAccount
  CARS_RESOURCE_INFO_TYPE_workflowTemplate
  CARS_RESOURCE_INFO_TYPE_url
  CARS_RESOURCE_INFO_TYPE_application
  CARS_RESOURCE_INFO_TYPE_messageQueue
  CARS_RESOURCE_INFO_TYPE_tcb
  CARS_RESOURCE_INFO_TYPE_sudo
  CARS_RESOURCE_INFO_TYPE_netIncoming
  CARS_RESOURCE_INFO_TYPE_netOutgoing
  CARS_RESOURCE_INFO_TYPE_file
  CARS_RESOURCE_INFO_TYPE_surrogate
  CARS_RESOURCE_INFO_TYPE_login
  CARS_RESOURCE_INFO_TYPE_policyUpdate
  CARS_RESOURCE_INFO_TYPE_junction
  CARS_RESOURCE_INFO_TYPE_management
  CARS_RESOURCE_INFO_TYPE_protectedResource
*/


/*                            Common Audit definitions                              */
/* -------------------------------------------------------------------------------- */


#endif
